@@ -23,3 +23,11 @@ Tag.__new__.__defaults__ = (None, None, False)
 HttpUrl = 'url'
 HttpMethod = 'http.method'
 HttpStatus = 'status.code'
+DbType = 'db.type'
+DbInstance = 'db.instance'
+DbStatement = 'db.statement'
+DbSqlParameters = 'db.sql.parameters'
+HttpParams = 'http.params'
+MqBroker = 'mq.broker'
+MqTopic = 'mq.topic'
+MqQueue = 'mq.queue'
